@@ -1,22 +1,30 @@
 """SatNOGS Network API django rest framework Views"""
+from random import choices
+from string import ascii_letters, digits
+
 from django.conf import settings
+from django.core.cache import cache
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import transaction
 from django.db.models import Count
 from django.db.models.query import QuerySet
+from django.http import HttpResponseRedirect
 from django.shortcuts import get_object_or_404
 from django.utils.timezone import now
 from rest_framework import mixins, status, viewsets
+from rest_framework.decorators import api_view, permission_classes
+from rest_framework.permissions import AllowAny, IsAuthenticated
 from rest_framework.response import Response
+from rest_framework.reverse import reverse
 from rest_framework.serializers import ValidationError
 
-from network.api import filters, pagination, serializers
+from network.api import authentication, filters, pagination, serializers
 from network.api.perms import StationOwnerPermission
 from network.base.models import Observation, Station
 from network.base.rating_tasks import rate_observation
 from network.base.tasks import delay_task_with_lock, process_audio, sync_to_db
 from network.base.validators import NegativeElevationError, NoTleSetError, \
-    ObservationOverlapError, SinglePassError
+    ObservationOverlapError, SchedulingLimitError, SinglePassError
 
 
 class ObservationView(  # pylint: disable=R0901
@@ -63,7 +71,7 @@ class ObservationView(  # pylint: disable=R0901
             response = Response(str(error), status=status.HTTP_400_BAD_REQUEST)
         except NoTleSetError as error:
             response = Response(str(error), status=status.HTTP_501_NOT_IMPLEMENTED)
-        except ObservationOverlapError as error:
+        except (ObservationOverlapError, SchedulingLimitError) as error:
             response = Response(str(error), status=status.HTTP_409_CONFLICT)
         return response
 
@@ -134,12 +142,45 @@ class StationView(  # pylint: disable=R0901
     """SatNOGS Network Station API view class"""
     queryset = Station.objects.annotate(
         total_obs=Count('observations'),
-    ).prefetch_related('antennas', 'antennas__antenna_type', 'antennas__frequency_ranges')
+    ).order_by('id').prefetch_related(
+        'antennas', 'antennas__antenna_type', 'antennas__frequency_ranges'
+    )
     serializer_class = serializers.StationSerializer
     filterset_class = filters.StationViewFilter
     pagination_class = pagination.LinkedHeaderPageNumberPagination
 
 
+class StationConfigurationView(viewsets.ReadOnlyModelViewSet):  # pylint: disable=R0901
+    """SatNOGS Network Station Configuration API view class"""
+    queryset = Station.objects.all()
+    serializer_class = serializers.StationConfigurationSerializer
+    authentication_classes = [authentication.ClientIDAuthentication]
+    permission_classes = [IsAuthenticated]
+
+    def list(self, request, *args, **kwargs):
+        station = get_object_or_404(Station, client_id=request.auth)
+        return HttpResponseRedirect(redirect_to='/api/configuration/' + str(station.id) + '/')
+
+
+@api_view(['POST'])
+@permission_classes((AllowAny, ))
+def station_register_view(request):
+    """ API endpoint for receiving client_id and return url for registering new station or connect
+        client_id to existing one
+    """
+    client_id = request.POST.get('client_id', None)
+    if client_id:
+        if Station.objects.filter(client_id=client_id).exists():
+            error = 'Invalid Client ID, please restart the "Station Registration" process.'
+            return Response(error, status=status.HTTP_400_BAD_REQUEST)
+        url_hash = ''.join(choices(ascii_letters + digits, k=60))
+        cache.set(url_hash, client_id, 60 * 10)
+        path = reverse('base:station_register', kwargs={'step': 1}) + '?hash=' + url_hash
+        url = request.build_absolute_uri(path)
+        return Response(data={'url': url}, status=status.HTTP_200_OK)
+    return HttpResponseRedirect(redirect_to='/api/')
+
+
 class TransmitterView(  # pylint: disable=R0901
         mixins.ListModelMixin, mixins.RetrieveModelMixin, viewsets.GenericViewSet):
     """SatNOGS Network Transmitter API view class"""
