@@ -17,7 +17,6 @@ from django.urls import reverse
 from django.utils.html import format_html
 from django.utils.timezone import now
 from PIL import Image
-from rest_framework.authtoken.models import Token
 from shortuuidfield import ShortUUIDField
 from storages.backends.s3boto3 import S3Boto3Storage
 
@@ -37,6 +36,11 @@ STATION_STATUSES = (
     (1, 'Testing'),
     (0, 'Offline'),
 )
+STATION_VIOLATOR_SCHEDULING_CHOICES = (
+    (0, 'Noone'),
+    (1, 'Only Operators'),
+    (2, 'Everyone'),
+)
 SATELLITE_STATUS = ['alive', 'dead', 'future', 're-entered']
 TRANSMITTER_STATUS = ['active', 'inactive', 'invalid']
 TRANSMITTER_TYPE = ['Transmitter', 'Transceiver', 'Transponder']
@@ -105,12 +109,18 @@ class Station(models.Model):
     )
     name = models.CharField(max_length=45)
     image = models.ImageField(upload_to='ground_stations', blank=True, validators=[validate_image])
-    alt = models.PositiveIntegerField(help_text='In meters above sea level')
+    alt = models.PositiveIntegerField(null=True, blank=True, help_text='In meters above sea level')
     lat = models.FloatField(
-        validators=[MaxValueValidator(90), MinValueValidator(-90)], help_text='eg. 38.01697'
+        null=True,
+        blank=True,
+        validators=[MaxValueValidator(90), MinValueValidator(-90)],
+        help_text='eg. 38.01697'
     )
     lng = models.FloatField(
-        validators=[MaxValueValidator(180), MinValueValidator(-180)], help_text='eg. 23.7314'
+        null=True,
+        blank=True,
+        validators=[MaxValueValidator(180), MinValueValidator(-180)],
+        help_text='eg. 23.7314'
     )
     # https://en.wikipedia.org/wiki/Maidenhead_Locator_System
     qthlocator = models.CharField(max_length=8, blank=True)
@@ -119,6 +129,9 @@ class Station(models.Model):
     testing = models.BooleanField(default=True)
     last_seen = models.DateTimeField(null=True, blank=True)
     status = models.IntegerField(choices=STATION_STATUSES, default=0)
+    violator_scheduling = models.IntegerField(
+        choices=STATION_VIOLATOR_SCHEDULING_CHOICES, default=0
+    )
     horizon = models.PositiveIntegerField(help_text='In degrees above 0', default=10)
     description = models.TextField(max_length=500, blank=True, help_text='Max 500 characters')
     client_version = models.CharField(max_length=45, blank=True)
@@ -129,6 +142,12 @@ class Station(models.Model):
         null=True,
         blank=True
     )
+    client_id = models.CharField(max_length=128, blank=True)
+    # Basic client configuration
+    satnogs_soapy_rx_device = models.CharField(max_length=40, blank=True)
+    satnogs_antenna = models.CharField(max_length=40, blank=True)
+    satnogs_rx_samp_rate = models.PositiveIntegerField(null=True, blank=True)
+    satnogs_rf_gain = models.FloatField(null=True, blank=True)
 
     class Meta:
         ordering = ['-status']
@@ -154,6 +173,13 @@ class Station(models.Model):
         """Return true if station is offline"""
         return not self.is_online
 
+    @property
+    def has_location(self):
+        """Return true if station location is defined"""
+        if self.alt is None or self.lat is None or self.lng is None:
+            return False
+        return True
+
     @property
     def is_testing(self):
         """Return true if station is online and in testing mode"""
@@ -192,15 +218,6 @@ class Station(models.Model):
                 rate = False
         return rate
 
-    @property
-    def apikey(self):
-        """Return station owner API key"""
-        try:
-            token = Token.objects.get(user=self.owner)
-        except Token.DoesNotExist:
-            token = Token.objects.create(user=self.owner)
-        return token
-
     def __str__(self):
         if self.pk:
             return "%d - %s" % (self.pk, self.name)
@@ -336,6 +353,7 @@ class Satellite(models.Model):
     status = models.CharField(
         choices=list(zip(SATELLITE_STATUS, SATELLITE_STATUS)), max_length=10, default='alive'
     )
+    is_frequency_violator = models.BooleanField(default=False)
 
     class Meta:
         ordering = ['norad_cat_id']
