@@ -19,23 +19,27 @@ from network.base.db_api import DBConnectionError, get_tle_set_by_norad_id, get_
 from network.base.decorators import ajax_required
 from network.base.forms import ObservationFormSet, SatelliteFilterForm
 from network.base.models import Observation, Satellite, Station
-from network.base.perms import schedule_perms
+from network.base.perms import schedule_perms, schedule_station_violators_perms
 from network.base.scheduling import create_new_observation, get_available_stations, \
     predict_available_observation_windows
 from network.base.serializers import StationSerializer
 from network.base.stats import satellite_stats_by_transmitter_list, transmitters_with_stats
 from network.base.validators import NegativeElevationError, NoTleSetError, \
-    ObservationOverlapError, SinglePassError, is_transmitter_in_station_range
+    ObservationOverlapError, SchedulingLimitError, SinglePassError, \
+    check_violators_scheduling_limit, is_transmitter_in_station_range
 
 
 def create_new_observations(formset, user):
     """Creates new observations from formset. Error handling is performed by upper layers."""
     new_observations = []
+    observations_per_norad_id = defaultdict(list)
     for observation_data in formset.cleaned_data:
         transmitter_uuid = observation_data['transmitter_uuid']
         transmitter = formset.transmitters[transmitter_uuid]
         tle_set = formset.tle_sets[transmitter['norad_cat_id']]
 
+        observations_per_norad_id[transmitter['norad_cat_id']].append(observation_data['start'])
+
         observation = create_new_observation(
             station=observation_data['ground_station'],
             transmitter=transmitter,
@@ -46,6 +50,9 @@ def create_new_observations(formset, user):
         )
         new_observations.append(observation)
 
+    if formset.violators and not user.groups.filter(name='Operators').exists():
+        check_violators_scheduling_limit(formset.violators, observations_per_norad_id)
+
     for observation in new_observations:
         observation.save()
 
@@ -84,7 +91,7 @@ def observation_new_post(request):
             messages.success(request, str(total) + ' Observations were scheduled successfully.')
             response = redirect(reverse('base:observations_list'))
     except (ObservationOverlapError, NegativeElevationError, NoTleSetError, SinglePassError,
-            ValidationError, ValueError) as error:
+            ValidationError, ValueError, SchedulingLimitError) as error:
         messages.error(request, str(error))
         response = redirect(reverse('base:observation_new'))
     return response
@@ -164,14 +171,15 @@ def prediction_windows(request):
 
     # Check the selected satellite exists and is alive
     try:
-        sat = Satellite.objects.filter(status='alive').get(norad_cat_id=params['sat_norad_id'])
+        satellite = Satellite.objects.filter(status='alive'
+                                             ).get(norad_cat_id=params['sat_norad_id'])
     except Satellite.DoesNotExist:
         data = [{'error': 'You should select a Satellite first.'}]
         return JsonResponse(data, safe=False)
 
     try:
         # Check if there is a TLE available for this satellite
-        tle_set = get_tle_set_by_norad_id(sat.norad_cat_id)
+        tle_set = get_tle_set_by_norad_id(satellite.norad_cat_id)
         if tle_set:
             tle = tle_set[0]
         else:
@@ -190,7 +198,9 @@ def prediction_windows(request):
         return JsonResponse(data, safe=False)
 
     # Fetch all available ground stations
-    stations = Station.objects.filter(status__gt=0).prefetch_related(
+    stations = Station.objects.filter(
+        status__gt=0, alt__isnull=False, lat__isnull=False, lng__isnull=False
+    ).prefetch_related(
         Prefetch(
             'observations',
             queryset=Observation.objects.filter(end__gt=now()),
@@ -203,12 +213,26 @@ def prediction_windows(request):
         stations = stations.filter(id__in=params['station_ids'])
         if not stations:
             if len(params['station_ids']) == 1:
-                data = [{'error': 'Station is offline or it doesn\'t exist.'}]
+                data = [
+                    {
+                        'error': (
+                            'Station is offline, it doesn\'t exist or'
+                            ' it hasn\'t defined location.'
+                        )
+                    }
+                ]
             else:
-                data = [{'error': 'Stations are offline or they don\'t exist.'}]
+                data = [
+                    {
+                        'error': (
+                            'Stations are offline, they don\'t exist or'
+                            ' they haven\'t defined location.'
+                        )
+                    }
+                ]
             return JsonResponse(data, safe=False)
 
-    available_stations = get_available_stations(stations, downlink, request.user)
+    available_stations = get_available_stations(stations, downlink, request.user, satellite)
 
     data = []
     passes_found = defaultdict(list)
@@ -263,10 +287,15 @@ def pass_predictions(request, station_id):
                 to_attr='scheduled_obs'
             ), 'antennas', 'antennas__frequency_ranges'
         ),
-        id=station_id
+        id=station_id,
+        alt__isnull=False,
+        lat__isnull=False,
+        lng__isnull=False
     )
 
     satellites = Satellite.objects.filter(status='alive')
+    if not schedule_station_violators_perms(request.user, station):
+        satellites = satellites.filter(is_frequency_violator='False')
 
     nextpasses = []
     start = make_aware(datetime.utcnow(), utc)
@@ -363,13 +392,18 @@ def scheduling_stations(request):
         if downlink is None:
             data = [{'error': 'You should select a valid Transmitter.'}]
             return JsonResponse(data, safe=False)
+        satellite = Satellite.objects.get(norad_cat_id=transmitter[0]['norad_cat_id'])
     except DBConnectionError as error:
         data = [{'error': str(error)}]
         return JsonResponse(data, safe=False)
+    except Satellite.DoesNotExist:
+        data = {'error': 'Unable to find satellite for the selected transmitter.'}
+        return JsonResponse(data, safe=False)
 
-    stations = Station.objects.filter(status__gt=0
-                                      ).prefetch_related('antennas', 'antennas__frequency_ranges')
-    available_stations = get_available_stations(stations, downlink, request.user)
+    stations = Station.objects.filter(
+        status__gt=0, alt__isnull=False, lat__isnull=False, lng__isnull=False
+    ).prefetch_related('antennas', 'antennas__frequency_ranges')
+    available_stations = get_available_stations(stations, downlink, request.user, satellite)
     data = {
         'stations': StationSerializer(available_stations, many=True).data,
     }
@@ -383,7 +417,7 @@ def transmitters_view(request):
     station_id = request.POST.get('station_id', None)
     try:
         if norad_id:
-            Satellite.objects.get(norad_cat_id=norad_id)
+            satellite = Satellite.objects.get(norad_cat_id=norad_id)
         else:
             data = {'error': 'Satellite not provided.'}
             return JsonResponse(data, safe=False)
@@ -405,6 +439,10 @@ def transmitters_view(request):
         station = Station.objects.prefetch_related('antennas', 'antennas__frequency_ranges').get(
             id=station_id
         )
+        if satellite.is_frequency_violator and not schedule_station_violators_perms(request.user,
+                                                                                    station):
+            data = {'error': 'No permission to schedule this satellite on this station.'}
+            return JsonResponse(data, safe=False)
         for transmitter in transmitters:
             transmitter_supported = is_transmitter_in_station_range(transmitter, station)
             if transmitter_supported:
