@@ -4,13 +4,14 @@ For local installation settings please copy .env-dist to .env and edit
 the appropriate settings in that file. You should not need to edit this
 file for local settings!
 """
+from pathlib import Path
+
 from decouple import Csv, config
 from dj_database_url import parse as db_url
 from sentry_sdk import init as sentry_sdk_init
 from sentry_sdk.integrations.celery import CeleryIntegration
 from sentry_sdk.integrations.django import DjangoIntegration
 from sentry_sdk.integrations.redis import RedisIntegration
-from unipath import Path
 
 from network import __version__
 
@@ -32,7 +33,6 @@ DJANGO_APPS = (
     'django.contrib.humanize',
 )
 THIRD_PARTY_APPS = (
-    'avatar',
     'rest_framework',
     'rest_framework.authtoken',
     'drf_spectacular',
@@ -105,13 +105,13 @@ CACHES = {
             default='django.core.cache.backends.locmem.LocMemCache',
         ),
         'LOCATION': config('CACHE_LOCATION', default='unique-location'),
-        'OPTIONS': {
-            'MAX_ENTRIES': 5000,
-            'CLIENT_CLASS': config('CACHE_CLIENT_CLASS', default=''),
-        },
         'KEY_PREFIX': 'network-{0}'.format(ENVIRONMENT),
     }
 }
+
+if CACHES['default']['BACKEND'] == 'django.core.cache.backends.locmem.LocMemCache':
+    CACHES['default']['OPTIONS'] = {'MAX_ENTRIES': 5000}
+
 CACHE_TTL = config('CACHE_TTL', default=300, cast=int)
 
 # Internationalization
@@ -127,7 +127,7 @@ TEMPLATES = [
     {
         'BACKEND': 'django.template.backends.django.DjangoTemplates',
         'DIRS': [
-            Path(ROOT).child('templates').resolve(),
+            Path(ROOT).joinpath('templates').resolve(),
         ],
         'OPTIONS': {
             'context_processors': [
@@ -161,7 +161,7 @@ TEMPLATES = [
 STATIC_ROOT = config('STATIC_ROOT', default=Path('staticfiles').resolve())
 STATIC_URL = config('STATIC_URL', default='/static/')
 STATICFILES_DIRS = [
-    Path(ROOT).child('static').resolve(),
+    Path(ROOT).joinpath('static').resolve(),
 ]
 STATICFILES_FINDERS = (
     'django.contrib.staticfiles.finders.FileSystemFinder',
@@ -181,7 +181,8 @@ COMPRESS_FILTERS = {
     'css': [
         'compressor.filters.css_default.CssAbsoluteFilter',
         'compressor.filters.cssmin.rCSSMinFilter'
-    ]
+    ],
+    'js': ['compressor.filters.jsmin.JSMinFilter']
 }
 COMPRESS_PRECOMPILERS = (('text/scss', 'sass --scss {infile} {outfile}'), )
 
@@ -201,6 +202,7 @@ AWS_QUERYSTRING_AUTH = config('AWS_QUERYSTRING_AUTH', default=False, cast=bool)
 # App conf
 ROOT_URLCONF = 'network.urls'
 WSGI_APPLICATION = 'network.wsgi.application'
+DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
 TEST_RUNNER = 'django.test.runner.DiscoverRunner'
 
 # Auth
@@ -339,7 +341,11 @@ SECURE_HSTS_SECONDS = config('SECURE_HSTS_SECONDS', default=31536000, cast=int)
 SECURE_HSTS_INCLUDE_SUBDOMAINS = True
 SECURE_CONTENT_TYPE_NOSNIFF = True
 SECURE_BROWSER_XSS_FILTER = True
+SECURE_PROXY_SSL_HEADER = config(
+    'SECURE_PROXY_SSL_HEADER', default='', cast=Csv(post_process=tuple)
+) or None
 ALLOWED_HOSTS = config('ALLOWED_HOSTS', default='localhost', cast=Csv())
+CSRF_TRUSTED_ORIGINS = config('CSRF_TRUSTED_ORIGINS', default='', cast=Csv())
 CSP_DEFAULT_SRC = config(
     'CSP_DEFAULT_SRC',
     cast=lambda v: tuple(s.strip() for s in v.split(',')),
@@ -423,6 +429,13 @@ ARCHIVE_AUDIO_LOCK_EXPIRATION = config('ARCHIVE_AUDIO_LOCK_EXPIRATION', default=
 NOT_SYNCED_MODES = config(
     'NOT_SYNCED_MODES', default='AHRPT,AM,APT,CW,FM,FMN,HRPT,LRPT,LSB,SSTV,USB', cast=Csv()
 )
+# Observations per Satellite that is frequency violator
+OBSERVATIONS_PER_VIOLATOR_SATELLITE = config(
+    'OBSERVATIONS_PER_VIOLATOR_SATELLITE', default=2, cast=int
+)
+OBSERVATIONS_PER_VIOLATOR_SATELLITE_PERIOD = config(
+    'OBSERVATIONS_PER_VIOLATOR_SATELLITE_PERIOD', default=86400, cast=int
+)
 
 # Station settings
 # Heartbeat for keeping a station online in minutes
@@ -468,9 +481,6 @@ COMMUNITY_TIMEOUT = config('COMMUNITY_TIMEOUT', default=2.0, cast=float)
 # ListView pagination
 ITEMS_PER_PAGE = config('ITEMS_PER_PAGE', default=25, cast=int)
 
-# User settings
-AVATAR_GRAVATAR_DEFAULT = config('AVATAR_GRAVATAR_DEFAULT', default='mm')
-
 # Cache expiration of the lock for "process audio" task
 PROCESS_AUDIO_LOCK_EXPIRATION = config('PROCESS_AUDIO_LOCK_EXPIRATION', default=900, cast=int)
 
